==> randovania-8.7.0-py3-none-any.whl: randovania/games/dread/gui/preset_settings/dread_patches_chaos.py <==
from __future__ import annotations

import typing

from PySide6 import QtWidgets

from randovania.games.dread.gui.generated.preset_dread_chaos_ui import Ui_PresetDreadChaos
from randovania.gui.lib import signal_handling
from randovania.gui.preset_settings.preset_tab import PresetTab

if typing.TYPE_CHECKING:
    from randovania.game_description.game_description import GameDescription
    from randovania.gui.lib.window_manager import WindowManager
    from randovania.interface_common.preset_editor import PresetEditor
    from randovania.layout.preset import Preset

_FIELDS = [
    "freesink",
]


class PresetDreadChaos(PresetTab, Ui_PresetDreadChaos):
    def __init__(self, editor: PresetEditor, game_description: GameDescription, window_manager: WindowManager):
        super().__init__(editor, game_description, window_manager)
        self.setupUi(self)

        self.chaos_label.setText(self.chaos_label.text().replace("color:#0000ff;", ""))

        # Signals
        for f in _FIELDS:
            self._add_persist_option(getattr(self, f"{f}_check"), f)

    @classmethod
    def tab_title(cls) -> str:
        return "Chaos Settings"

    @classmethod
    def is_experimental(cls) -> bool:
        return True

    @classmethod
    def header_name(cls) -> str | None:
        return None

    def _add_persist_option(self, check: QtWidgets.QCheckBox, attribute_name: str):
        def persist(value: bool):
            with self._editor as editor:
                editor.set_configuration_field(attribute_name, value)

        signal_handling.on_checked(check, persist)

    def on_preset_changed(self, preset: Preset):
        config = preset.configuration

        for f in _FIELDS:
            typing.cast(QtWidgets.QCheckBox, getattr(self, f"{f}_check")).setChecked(getattr(config, f))

==> randovania-8.9.0-py3-none-any.whl: randovania/games/dread/gui/preset_settings/dread_patches_chaos.py <==
from __future__ import annotations

import typing

from PySide6 import QtWidgets

from randovania.games.dread.gui.generated.preset_dread_chaos_ui import Ui_PresetDreadChaos
from randovania.gui.lib import signal_handling
from randovania.gui.preset_settings.preset_tab import PresetTab

if typing.TYPE_CHECKING:
    from randovania.game_description.game_description import GameDescription
    from randovania.gui.lib.window_manager import WindowManager
    from randovania.interface_common.preset_editor import PresetEditor
    from randovania.layout.preset import Preset

_FIELDS = [
    "freesink",
]


class PresetDreadChaos(PresetTab, Ui_PresetDreadChaos):
    def __init__(self, editor: PresetEditor, game_description: GameDescription, window_manager: WindowManager):
        super().__init__(editor, game_description, window_manager)
        self.setupUi(self)

        self.chaos_label.setText(self.chaos_label.text().replace("color:#0000ff;", ""))

        # Signals
        for f in _FIELDS:
            self._add_persist_option(getattr(self, f"{f}_check"), f)

    @classmethod
    def tab_title(cls) -> str:
        return "Chaos Settings"

    @classmethod
    def is_experimental(cls) -> bool:
        return True

    @classmethod
    def header_name(cls) -> str | None:
        return None

    def _add_persist_option(self, check: QtWidgets.QCheckBox, attribute_name: str) -> None:
        def persist(value: bool) -> None:
            with self._editor as editor:
                editor.set_configuration_field(attribute_name, value)

        signal_handling.on_checked(check, persist)

    def on_preset_changed(self, preset: Preset) -> None:
        config = preset.configuration

        for f in _FIELDS:
            typing.cast(QtWidgets.QCheckBox, getattr(self, f"{f}_check")).setChecked(getattr(config, f))
